{pkgs', ...}: let
  bashFktScript = import ./bash-fkt.nix {
    inherit pkgs';
  };
in
  pkgs'.writeShellScriptBin "update-project" ''

    source ${pkgs'.common}/bin/common
    ${bashFktScript}

    echo_header "Update project"
    echo_hint "The command is executed in the current working directory and not in a nix derivation."
    cd_working_dir

    currentVersion=$(${pkgs'.version}/bin/version print -e -g)
    currentHash=$(${pkgs'.git}/bin/git rev-parse HEAD)

    echo_step "Write project version"
    export VERSION=$currentVersion
    export COMMIT=$currentHash

    export NAME=$(basename $(pwd) | sed 's/./\U&/' | sed 's/-//g')
    export MNEMONIC=$(echo $NAME | tr '[:upper:]' '[:lower:]' | sed 's/[^a-z0-9]//g')

    ${pkgs'.envsubst}/bin/envsubst < ./nix/config/release.nix.template > ./nix/config/release.nix

    echo_step "Formatting Nix code"
    if ! ${pkgs'.alejandra}/bin/alejandra flake.nix ./nix/scripts/*.nix ./nix/config/*.nix ./nix/packages/*nix
    then
      echo_fail "alejandra formatting failed"
      exit 1
    fi

    echo_step "change working directory to source"
    setup_go_env
    echo_step "Formatting Go code"
    if ! ${pkgs'.findutils}/bin/find . -type f -name '*.go' ! -path './vendor/*' -print0 | xargs -0 gofmt -s -w
    then
      echo_fail "go fmt failed"
      exit 1
    fi

    echo_step "Add license headers"
    if ! ${pkgs'.addlicense}/bin/addlicense -c "schukai GmbH" -s -l "proprietary" $(${pkgs'.fd}/bin/fd --extension go --exclude models/ --exclude vendor --exclude embedded/)
    then
      echo_fail "addlicense failed"
      exit 1
    fi

    export NIX_CFLAGS_COMPILE=" -Wno-error=format-security"

    echo_step "Running go-licenses"
    readonly defaultPacke=$(awk -F ' ' '/^module / { print $2 }' ./go.mod)
    ${pkgs'.go-licenses}/bin/go-licenses save "$defaultPacke" -v2 --ignore "gitlab.schukai.com" --force --save_path ./documentation/licenses/

    echo_step "Running go vet"
    if ! ${pkgs'.go}/bin/go vet .
    then
      echo_fail "go vet failed"
      exit 1
    fi

    echo_step "Running go mod tidy"
    if ! ${pkgs'.go}/bin/go mod tidy
    then
      echo_fail "go mod tidy failed"
      exit 1
    fi

    echo_step "Running lint"
    if ! ${pkgs'.golangci-lint}/bin/golangci-lint run .
    then
      echo_fail "lint failed"
      exit 1
    fi

    echo_step "Running gosec"
    if ! ${pkgs'.gosec}/bin/gosec -quiet .
    then
      echo_fail "gosec failed"
      exit 1
    fi


  ''
